@@ -20,6 +20,8 @@ class ParamMessage:
     DIST_FILE = "dist_file"
     DO_NOT_DELETE = "do_not_delete"
     MIMETYPE_STR = "mimetype_str"
+    DISPLAY = "display"
+    GROUP_IDS = "group_ids"
 
 
 class ParamMessageSaveInfoFile(ParamMessage):
@@ -30,6 +32,26 @@ class ParamMessageUploadMediaSdk(ParamMessage):
     TMP_FILE = "tmp_file"
 
 
+class Display:
+    DISPLAY_SDK = "display_sdk_1638219620"
+    LIST = "LIST"
+
+
+class ParamPayload:
+    X_MERCHANT_ID = "X-Merchant-ID"
+    FILE = "file"
+    WITH_EXTENSION = "with_extension"
+    USE_NAME = "use_name"
+    FILE_NAME = "filename"
+    GROUP_IDS = "group_ids"
+    EXPIRE = "expire"
+    TAGS = "tags"
+    DO_NOT_DELETE = "do_not_delete"
+    FILETYPE = "filetype"
+    DISPLAY = "display"
+    DESIRED_FORMAT = "desired_format"
+
+
 CONSTANT_MAP_FORMAT_FILE = {
     "image": [
         'image/bmp', 'image/gif', 'image/ief', 'image/jpeg', 'image/jpeg', 'image/jpeg', 'image/png',
