@@ -15,7 +15,7 @@ from mobio.libs.caching import LruCache
 
 from .config import ConsumerTopic, MobioEnvironment, StoreCacheType, Cache
 from .constant import DirSaveFile, FieldConstantResponse, CONSTANT_MAP_FORMAT_FILE, ParamMessageSaveInfoFile, \
-    ParamMessageUploadMediaSdk
+    ParamMessageUploadMediaSdk, Display
 from .custom_mimetypes import CustomMimetypes
 from .dir import APP_TMP_DATA_DIR, STATIC_DATA_DIR
 
@@ -111,7 +111,9 @@ class MobioMediaSDK(object):
             expire=None,
             do_not_delete: bool = False,
             short_link: bool = False,
-            desired_format=None
+            desired_format=None,
+            display=Display.DISPLAY_SDK,
+            group_ids=None
     ):
         """
         :param merchant_id:
@@ -125,6 +127,8 @@ class MobioMediaSDK(object):
         :param do_not_delete
         :param short_link: rút gọn lịnk
         :param desired_format: định dạng mong muốn khi upload
+        :param display: Khu vực hiển thị, trong trường hợp không cần hiện thị thì mặc định là no_display_1638219620
+        :param group_ids: Danh sách folder cần upload
 
         "return:
         {
@@ -168,13 +172,16 @@ class MobioMediaSDK(object):
         logger.debug("upload_without_kafka()::url:: %s" % (time.time() - time_start))
         data_send_producer = {
             ParamMessageSaveInfoFile.FILENAME: filename,
+            ParamMessageSaveInfoFile.MERCHANT_ID: merchant_id,
             ParamMessageSaveInfoFile.URL: url,
             ParamMessageSaveInfoFile.TYPE_MEDIA: type_media,
             ParamMessageSaveInfoFile.TAG: tag,
             ParamMessageSaveInfoFile.EXPIRE: expire,
             ParamMessageSaveInfoFile.DIST_FILE: dist_file,
             ParamMessageSaveInfoFile.MIMETYPE_STR: mimetype_str,
-            ParamMessageSaveInfoFile.DO_NOT_DELETE: do_not_delete
+            ParamMessageSaveInfoFile.DO_NOT_DELETE: do_not_delete,
+            ParamMessageSaveInfoFile.GROUP_IDS: group_ids,
+            ParamMessageSaveInfoFile.DISPLAY: display
         }
 
         self.send_message_to_topic(topic=ConsumerTopic.TOPIC_SAVE_INFO_MEDIA_SDK, data=json.dumps(data_send_producer))
@@ -198,7 +205,9 @@ class MobioMediaSDK(object):
             expire=None,
             do_not_delete=False,
             short_link=False,
-            desired_format=None
+            desired_format=None,
+            display=Display.DISPLAY_SDK,
+            group_ids=None
     ):
         """
         :param merchant_id:
@@ -213,6 +222,8 @@ class MobioMediaSDK(object):
         :param do_not_delete:
         :param short_link:
         :param desired_format: định dạng mong muốn khi upload
+        :param display: Khu vực hiển thị, trong trường hợp không cần hiện thị thì mặc định là no_display_1638219620
+        :param group_ids: Danh sách folder cần upload
 
         :return:
         {
@@ -270,7 +281,9 @@ class MobioMediaSDK(object):
             ParamMessageUploadMediaSdk.DIST_FILE: dist_file,
             ParamMessageUploadMediaSdk.MIMETYPE_STR: mimetype_str,
             ParamMessageUploadMediaSdk.DO_NOT_DELETE: do_not_delete,
-            ParamMessageUploadMediaSdk.URL: url
+            ParamMessageUploadMediaSdk.URL: url,
+            ParamMessageUploadMediaSdk.GROUP_IDS: group_ids,
+            ParamMessageUploadMediaSdk.DISPLAY: display
         }
         self.send_message_to_topic(topic=ConsumerTopic.TOPIC_UPLOAD_MEDIA_SDK, data=json.dumps(data_send_producer))
         logger.debug("upload_with_kafka()::send message to topic:: %s" % (time.time() - time_start))
@@ -290,7 +303,10 @@ class MobioMediaSDK(object):
             expire=None,
             do_not_delete=False,
             short_link=False,
-            mimetype_str=None
+            mimetype_str=None,
+            display=Display.DISPLAY_SDK,
+            group_ids=None
+
     ):
         dist_file, filename = self.create_dir_save_file(
             folder=STATIC_DATA_DIR,
@@ -317,7 +333,9 @@ class MobioMediaSDK(object):
             ParamMessageSaveInfoFile.DIST_FILE: dist_file,
             ParamMessageSaveInfoFile.DO_NOT_DELETE: do_not_delete,
             ParamMessageSaveInfoFile.MIMETYPE_STR: mimetype_str,
-            ParamMessageSaveInfoFile.NOT_CHECK_PATH_EXISTS: True
+            ParamMessageSaveInfoFile.NOT_CHECK_PATH_EXISTS: True,
+            ParamMessageSaveInfoFile.GROUP_IDS: group_ids,
+            ParamMessageSaveInfoFile.DISPLAY: display
         }
 
         self.send_message_to_topic(topic=ConsumerTopic.TOPIC_SAVE_INFO_MEDIA_SDK, data=json.dumps(data_send_producer))
